
#include <ESP8266WiFi.h>
#include <ESP8266mDNS.h>
#include <WiFiUdp.h>
#include <TimeLib.h>
#include <ArduinoOTA.h>
#include "SDA5708_ESP.h"
#include "Time_NTP.h"

#define HOSTNAME "OTA-DBOX"                   // Hostename. The setup function adds the Chip ID at the end.

const char* ssid = "xxxxxxxx";
const char* password = "xxxxxxxx";

char previousSecond = 0;

void WiFiStart(void);
void Get_NTP(void);
void ShowTime(void);
void ShowDate(void);

// create instance of display -> calls constructor which does the init, set pins as parameters
// SDA5708 sda5708(LOAD, DATA, SDCLK, RESET);
SDA5708 sda5708( 4, 12, 14, 13);

void setup()
{
  // set brightness
  // 0 == max, 7 == off, +8 reduziert Mux-Impulslänge
  sda5708.set_brightness(3);

  sda5708.print2display("SHOWTIME");

  // Set Hostname.
  String hostname(HOSTNAME);
  WiFi.hostname(hostname);

  // inital connect
  WiFi.mode(WIFI_STA);
  WiFiStart();

  delay(500);
  // Start OTA server.
  ArduinoOTA.setHostname((const char *)hostname.c_str());
  ArduinoOTA.begin();

  delay(500);
  Get_NTP();
}

void loop()
{
  // check if WLAN is connected
  if (WiFi.status() != WL_CONNECTED)
  {
    WiFiStart();
  }

  ArduinoOTA.handle();                      // Handle OTA server.

  if (previousSecond != second())   // neue Sekunde?
  {
    previousSecond = second();    // ja, aktuelle Sekunde merken

    if (second() % 15 < 2)        // alle 15 Sekunden für 2 Sekunden Datum anzeigen
    {
      ShowDate();
    }
    else
    {
      ShowTime();
    }

    if ((minute() == 0) && (second() == 0))  // NTP Zeit holen alle Stunde
    {
      Get_NTP();
    }
  }
}

//---------------------------------------------------------------------

void WiFiStart()
{
  // Connect to WiFi network

  WiFi.begin(ssid, password);

  while (WiFi.status() != WL_CONNECTED)
  {
    delay(500);
  }
}

//---------------------------------------------------------------------

void Get_NTP()
{
  if (WiFi.status() != WL_CONNECTED)
  {
    WiFiStart();
  }

  ///////////////////////////////
  // connect to NTP and get time
  ///////////////////////////////

  unsigned long ulSecs2000_timer = 0;
  date_time_t datum_zeit;

  ulSecs2000_timer = getNTPTimestamp();

  epoch_to_date_time(&datum_zeit, (ulSecs2000_timer + 3600));

  setTime(datum_zeit.hour, datum_zeit.minute, datum_zeit.second, datum_zeit.day, datum_zeit.month, datum_zeit.year);
}

//---------------------------------------------------------------------

void ShowTime()
{
  String stunden = String(hour(), DEC);
  if (hour() < 10)
  {
    stunden = "0" + stunden;
  }
  String minuten = String(minute(), DEC);
  if (minute() < 10)
  {
    minuten = "0" + minuten;
  }
  String sekunden = String(second(), DEC);
  if (second() < 10)
  {
    sekunden = "0" + sekunden;
  }

  String uhrzeit = stunden + ':' + minuten + ':' + sekunden;
  sda5708.print2display(uhrzeit);
}

//---------------------------------------------------------------------

void ShowDate()
{
  String tag = String(day(), DEC);
  if (day() < 10)
  {
    tag = "0" + tag;
  }
  String monat = String(month(), DEC);
  if (month() < 10)
  {
    monat = "0" + monat;
  }
  String jahr = String(year(), DEC);

  String datum = tag + '.' + monat + '.' + jahr.substring(2);
  sda5708.print2display(datum);
}

//---------------------------------------------------------------------


